***
API
***
.. autofunction:: formbar.config.load
.. autoclass:: formbar.config.Config
   :members: get_form
.. autoclass:: formbar.form.Form
   :members: render, validate, save, get_warnings, get_errors
.. autoclass:: formbar.renderer.FieldRenderer
.. autoclass:: formbar.renderer.InfoFieldRenderer
